@@ -1,19 +1,12 @@
-/*-------------------------------------------------------------------------
+/** Implementation of the pqxx::connection and sibling classes.
  *
- *   FILE
- *	connection.cxx
+ * Different ways of setting up a backend connection.
  *
- *   DESCRIPTION
- *      implementation of the pqxx::connection and sibling classes.
- *   Different ways of setting up a backend connection.
- *
- * Copyright (c) 2001-2008, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2001-2017, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
  * or contact the author.
- *
- *-------------------------------------------------------------------------
  */
 #include "pqxx/compiler-internal.hxx"
 
@@ -23,16 +16,14 @@
 
 #include "pqxx/connection"
 
-using namespace PGSTD;
 
-
-pqxx::connectionpolicy::connectionpolicy(const PGSTD::string &opts) :
+pqxx::connectionpolicy::connectionpolicy(const std::string &opts) :
   m_options(opts)
 {
 }
 
 
-pqxx::connectionpolicy::~connectionpolicy() throw ()
+pqxx::connectionpolicy::~connectionpolicy() noexcept
 {
 }
 
@@ -42,10 +33,10 @@ pqxx::connectionpolicy::normalconnect(handle orig)
 {
   if (orig) return orig;
   orig = PQconnectdb(options().c_str());
-  if (!orig) throw bad_alloc();
+  if (!orig) throw std::bad_alloc();
   if (PQstatus(orig) != CONNECTION_OK)
   {
-    const string msg(PQerrorMessage(orig));
+    const std::string msg(PQerrorMessage(orig));
     PQfinish(orig);
     throw broken_connection(msg);
   }
@@ -66,23 +57,23 @@ pqxx::connectionpolicy::do_completeconnect(handle orig)
 }
 
 pqxx::connectionpolicy::handle
-pqxx::connectionpolicy::do_dropconnect(handle orig) throw ()
+pqxx::connectionpolicy::do_dropconnect(handle orig) noexcept
 {
   return orig;
 }
 
 pqxx::connectionpolicy::handle
-pqxx::connectionpolicy::do_disconnect(handle orig) throw ()
+pqxx::connectionpolicy::do_disconnect(handle orig) noexcept
 {
   orig = do_dropconnect(orig);
   if (orig) PQfinish(orig);
-  return 0;
+  return nullptr;
 }
 
 
-bool pqxx::connectionpolicy::is_ready(handle h) const throw ()
+bool pqxx::connectionpolicy::is_ready(handle h) const noexcept
 {
-  return h != 0;
+  return h != nullptr;
 }
 
 
@@ -93,7 +84,7 @@ pqxx::connect_direct::do_startconnect(handle orig)
   orig = normalconnect(orig);
   if (PQstatus(orig) != CONNECTION_OK)
   {
-    const string msg(PQerrorMessage(orig));
+    const std::string msg(PQerrorMessage(orig));
     do_disconnect(orig);
     throw broken_connection(msg);
   }
@@ -108,7 +99,7 @@ pqxx::connect_lazy::do_completeconnect(handle orig)
 }
 
 
-pqxx::connect_async::connect_async(const PGSTD::string &opts) :
+pqxx::connect_async::connect_async(const std::string &opts) :
   connectionpolicy(opts),
   m_connecting(false)
 {
@@ -120,11 +111,11 @@ pqxx::connect_async::do_startconnect(handle orig)
   if (orig) return orig;	// Already connecting or connected
   m_connecting = false;
   orig = PQconnectStart(options().c_str());
-  if (!orig) throw bad_alloc();
-  if (PQconnectPoll(orig) == PGRES_POLLING_FAILED)
+  if (!orig) throw std::bad_alloc();
+  if (PQstatus(orig) == CONNECTION_BAD)
   {
     do_dropconnect(orig);
-    throw broken_connection(string(PQerrorMessage(orig)));
+    throw broken_connection(std::string(PQerrorMessage(orig)));
   }
   m_connecting = true;
   return orig;
@@ -141,16 +132,15 @@ pqxx::connect_async::do_completeconnect(handle orig)
   // Our "attempt to connect" state ends here, for better or for worse
   m_connecting = false;
 
-  PostgresPollingStatusType pollstatus;
+  PostgresPollingStatusType pollstatus = PGRES_POLLING_WRITING;
 
   do
   {
-    pollstatus = PQconnectPoll(orig);
     switch (pollstatus)
     {
     case PGRES_POLLING_FAILED:
       if (makenew) do_disconnect(orig);
-      throw broken_connection(string(PQerrorMessage(orig)));
+      throw broken_connection(std::string(PQerrorMessage(orig)));
 
     case PGRES_POLLING_READING:
       internal::wait_read(orig);
@@ -160,10 +150,15 @@ pqxx::connect_async::do_completeconnect(handle orig)
       internal::wait_write(orig);
       break;
 
-    case PGRES_POLLING_ACTIVE:
     case PGRES_POLLING_OK:
       break;
+
+    default:
+      // Meaningless, really, but deals with the obsolete PGRES_POLLING_ACTIVE
+      // without requiring it to be defined.
+      break;
     }
+    pollstatus = PQconnectPoll(orig);
   } while (pollstatus != PGRES_POLLING_OK);
 
   return orig;
@@ -171,15 +166,14 @@ pqxx::connect_async::do_completeconnect(handle orig)
 
 
 pqxx::connectionpolicy::handle
-pqxx::connect_async::do_dropconnect(handle orig) throw ()
+pqxx::connect_async::do_dropconnect(handle orig) noexcept
 {
   m_connecting = false;
   return orig;
 }
 
 
-bool pqxx::connect_async::is_ready(handle h) const throw ()
+bool pqxx::connect_async::is_ready(handle h) const noexcept
 {
-  return h && !m_connecting;
+  return h != nullptr && !m_connecting;
 }
-
