@@ -16,6 +16,7 @@
 #include <cstdio>
 #include <cstring>
 #include <ctime>
+#include <iterator>
 #include <memory>
 #include <stdexcept>
 
@@ -649,7 +650,7 @@ void pqxx::connection_base::unregister_errorhandler(errorhandler *handler)
 std::vector<errorhandler *> pqxx::connection_base::get_errorhandlers() const
 {
   return std::vector<errorhandler *>(
-    m_errorhandlers.begin(), m_errorhandlers.end());
+    std::begin(m_errorhandlers), std::end(m_errorhandlers));
 }
 
 
@@ -931,7 +932,8 @@ bool pqxx::connection_base::read_copy_line(std::string &Line)
 
   char *Buf = nullptr;
   const std::string query = "[END COPY]";
-  switch (PQgetCopyData(m_conn, &Buf, false))
+  const auto line_len = PQgetCopyData(m_conn, &Buf, false);
+  switch (line_len)
   {
   case -2:
     throw failure("Reading of table data failed: " + std::string(err_msg()));
@@ -954,7 +956,7 @@ bool pqxx::connection_base::read_copy_line(std::string &Line)
     {
       std::unique_ptr<char, void (*)(char *)> PQA(
           Buf, freepqmem_templated<char>);
-      Line = Buf;
+      Line.assign(Buf, line_len);
     }
     Result = true;
   }
