@@ -1,19 +1,12 @@
-/*-------------------------------------------------------------------------
+/** Implementation of pqxx::errorhandler and helpers.
  *
- *   FILE
- *	errorhandler.cxx
+ * pqxx::errorhandler allows programs to receive errors and warnings.
  *
- *   DESCRIPTION
- *      implementation of pqxx::errorhandler and helpers.
- *   pqxx::errorhandler allows programs to receive errors and warnings.
- *
- * Copyright (c) 2011, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2011-2017, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
  * or contact the author.
- *
- *-------------------------------------------------------------------------
  */
 #include "pqxx/compiler-internal.hxx"
 
@@ -40,12 +33,12 @@ pqxx::errorhandler::~errorhandler()
 }
 
 
-void pqxx::errorhandler::unregister() throw ()
+void pqxx::errorhandler::unregister() noexcept
 {
   if (m_home)
   {
     gate::connection_errorhandler connection_gate(*m_home);
-    m_home = NULL;
+    m_home = nullptr;
     connection_gate.unregister_errorhandler(this);
   }
 }
