@@ -1,19 +1,12 @@
-/*-------------------------------------------------------------------------
+/** Helper classes for defining and executing prepared statements>
  *
- *   FILE
- *	prepared_statement.cxx
+ * See the connection_base hierarchy for more about prepared statements.
  *
- *   DESCRIPTION
- *      Helper classes for defining and executing prepared statements
- *   See the connection_base hierarchy for more about prepared statements
- *
- * Copyright (c) 2006-2011, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2006-2017, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
  * or contact the author.
- *
- *-------------------------------------------------------------------------
  */
 #include "pqxx/compiler-internal.hxx"
 
@@ -25,15 +18,13 @@
 #include "pqxx/internal/gates/connection-prepare-invocation.hxx"
 
 
-using namespace PGSTD;
 using namespace pqxx;
 using namespace pqxx::internal;
 
 
 pqxx::prepare::invocation::invocation(
 	transaction_base &home,
-	const PGSTD::string &statement) :
-  statement_parameters(),
+	const std::string &statement) :
   m_home(home),
   m_statement(statement)
 {
@@ -42,16 +33,16 @@ pqxx::prepare::invocation::invocation(
 
 pqxx::result pqxx::prepare::invocation::exec() const
 {
-  scoped_array<const char *> ptrs;
-  scoped_array<int> lens;
-  scoped_array<int> binaries;
+  std::vector<const char *> ptrs;
+  std::vector<int> lens;
+  std::vector<int> binaries;
   const int elts = marshall(ptrs, lens, binaries);
 
   return gate::connection_prepare_invocation(m_home.conn()).prepared_exec(
 	m_statement,
-	ptrs.get(),
-	lens.get(),
-	binaries.get(),
+	&ptrs[0],
+	&lens[0],
+	&binaries[0],
 	elts);
 }
 
@@ -63,15 +54,7 @@ bool pqxx::prepare::invocation::exists() const
 }
 
 
-pqxx::prepare::internal::prepared_def::prepared_def() :
-  definition(),
-  registered(false)
-{
-}
-
-
-pqxx::prepare::internal::prepared_def::prepared_def(const PGSTD::string &def) :
-  definition(def),
-  registered(false)
+pqxx::prepare::internal::prepared_def::prepared_def(const std::string &def) :
+  definition(def)
 {
 }
