@@ -1,19 +1,12 @@
-/*-------------------------------------------------------------------------
+/** Implementation of the pqxx::robusttransaction class.
  *
- *   FILE
- *	robusttransaction.cxx
+ * pqxx::robusttransaction is a slower but safer transaction class.
  *
- *   DESCRIPTION
- *      implementation of the pqxx::robusttransaction class.
- *   pqxx::robusttransaction is a slower but safer transaction class
- *
- * Copyright (c) 2002-2009, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2002-2017, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
  * or contact the author.
- *
- *-------------------------------------------------------------------------
  */
 #include "pqxx/compiler-internal.hxx"
 
@@ -24,45 +17,40 @@
 #include "pqxx/robusttransaction"
 
 
-using namespace PGSTD;
 using namespace pqxx::internal;
 
 
 // TODO: Log username in more places.
 
-pqxx::basic_robusttransaction::basic_robusttransaction(
+pqxx::internal::basic_robusttransaction::basic_robusttransaction(
 	connection_base &C,
-	const PGSTD::string &IsolationLevel,
-	const PGSTD::string &table_name) :
+	const std::string &IsolationLevel,
+	const std::string &table_name) :
   namedclass("robusttransaction"),
   dbtransaction(C, IsolationLevel),
-  m_record_id(0),
-  m_xid(),
-  m_LogTable(table_name),
-  m_sequence(),
-  m_backendpid(-1)
+  m_log_table(table_name)
 {
-  if (table_name.empty()) m_LogTable = "pqxx_robusttransaction_log";
-  m_sequence = m_LogTable + "_seq";
+  if (table_name.empty()) m_log_table = "pqxx_robusttransaction_log";
+  m_sequence = m_log_table + "_seq";
 }
 
 
-pqxx::basic_robusttransaction::~basic_robusttransaction()
+pqxx::internal::basic_robusttransaction::~basic_robusttransaction()
 {
 }
 
 
-void pqxx::basic_robusttransaction::do_begin()
+void pqxx::internal::basic_robusttransaction::do_begin()
 {
   try
   {
     CreateTransactionRecord();
   }
-  catch (const exception &)
+  catch (const std::exception &)
   {
     // The problem here *may* be that the log table doesn't exist yet.  Create
     // one, start a new transaction, and try again.
-    try { dbtransaction::do_abort(); } catch (const exception &) {}
+    try { dbtransaction::do_abort(); } catch (const std::exception &) {}
     CreateLogTable();
     dbtransaction::do_begin();
     m_backendpid = conn().backendpid();
@@ -72,15 +60,15 @@ void pqxx::basic_robusttransaction::do_begin()
   dbtransaction::do_begin();
 
   // If this transaction commits, the transaction record should also be gone.
-  DirectExec(sql_delete().c_str());
+  direct_exec(sql_delete().c_str());
 
   if (conn().server_version() >= 80300)
-    DirectExec("SELECT txid_current()")[0][0].to(m_xid);
+    direct_exec("SELECT txid_current()")[0][0].to(m_xid);
 }
 
 
 
-void pqxx::basic_robusttransaction::do_commit()
+void pqxx::internal::basic_robusttransaction::do_commit()
 {
   if (!m_record_id)
     throw internal_error("transaction '" + name() + "' has no ID");
@@ -89,7 +77,7 @@ void pqxx::basic_robusttransaction::do_commit()
   // work being done inside our in-doubt window.
   try
   {
-    DirectExec("SET CONSTRAINTS ALL IMMEDIATE");
+    direct_exec("SET CONSTRAINTS ALL IMMEDIATE");
   }
   catch (...)
   {
@@ -104,7 +92,7 @@ void pqxx::basic_robusttransaction::do_commit()
   // is.
   try
   {
-    DirectExec(sql_commit_work);
+    direct_exec(sql_commit_work);
 
     // If we make it here, great.  Normal, successful commit.
     m_record_id = 0;
@@ -137,23 +125,24 @@ void pqxx::basic_robusttransaction::do_commit()
   {
     exists = CheckTransactionRecord();
   }
-  catch (const exception &f)
+  catch (const std::exception &f)
   {
     // Couldn't check for transaction record.  We're still in doubt as to
     // whether the transaction was performed.
-    const string Msg = "WARNING: "
-	"Connection lost while committing transaction "
+    const std::string Msg =
+	"WARNING: Connection lost while committing transaction "
 	"'" + name() + "' (id " + to_string(m_record_id) + ", "
 	"transaction_id " + m_xid + "). "
 	"Please check for this record in the "
-	"'" + m_LogTable + "' table.  "
+	"'" + m_log_table + "' table.  "
 	"If the record exists, the transaction was executed. "
 	"If not, then it wasn't.\n";
 
     process_notice(Msg);
-    process_notice("Could not verify existence of transaction record "
-	"because of the following error:\n");
-    process_notice(string(f.what()) + "\n");
+    process_notice(
+	"Could not verify existence of transaction record because of the "
+	"following error:\n");
+    process_notice(std::string(f.what()) + "\n");
 
     throw in_doubt_error(Msg);
   }
@@ -170,7 +159,7 @@ void pqxx::basic_robusttransaction::do_commit()
 }
 
 
-void pqxx::basic_robusttransaction::do_abort()
+void pqxx::internal::basic_robusttransaction::do_abort()
 {
   dbtransaction::do_abort();
   DeleteTransactionRecord();
@@ -178,11 +167,12 @@ void pqxx::basic_robusttransaction::do_abort()
 
 
 // Create transaction log table if it didn't already exist
-void pqxx::basic_robusttransaction::CreateLogTable()
+void pqxx::internal::basic_robusttransaction::CreateLogTable()
 {
   // Create log table in case it doesn't already exist.  This code must only be
   // executed before the backend transaction has properly started.
-  string CrTab = "CREATE TABLE \"" + m_LogTable + "\" ("
+  std::string CrTab =
+	"CREATE TABLE \"" + m_log_table + "\" ("
 	"id INTEGER NOT NULL, "
         "username VARCHAR(256), "
 	"transaction_id xid, "
@@ -192,41 +182,39 @@ void pqxx::basic_robusttransaction::CreateLogTable()
 
   try
   {
-    DirectExec(CrTab.c_str(), 1);
+    direct_exec(CrTab.c_str(), 1);
   }
-  catch (const exception &e)
+  catch (const std::exception &e)
   {
     conn().process_notice(
-	"Could not create transaction log table: " + string(e.what()));
+	"Could not create transaction log table: " + std::string(e.what()));
   }
 
   try
   {
-    DirectExec(("CREATE SEQUENCE " + m_sequence).c_str());
+    direct_exec(("CREATE SEQUENCE " + m_sequence).c_str());
   }
-  catch (const exception &e)
+  catch (const std::exception &e)
   {
     conn().process_notice(
-	"Could not create transaction log sequence: " + string(e.what()));
+	"Could not create transaction log sequence: " + std::string(e.what()));
   }
 }
 
 
-void pqxx::basic_robusttransaction::CreateTransactionRecord()
+void pqxx::internal::basic_robusttransaction::CreateTransactionRecord()
 {
-  static const string Fail = "Could not create transaction log record: ";
-
   // Clean up old transaction records.
-  DirectExec((
-	"DELETE FROM " + m_LogTable + " "
+  direct_exec((
+	"DELETE FROM " + m_log_table + " "
 	"WHERE date < CURRENT_TIMESTAMP - '30 days'::interval").c_str());
 
   // Allocate id.
-  const string sql_get_id("SELECT nextval(" + quote(m_sequence) + ")");
-  DirectExec(sql_get_id.c_str())[0][0].to(m_record_id);
+  const std::string sql_get_id("SELECT nextval(" + quote(m_sequence) + ")");
+  direct_exec(sql_get_id.c_str())[0][0].to(m_record_id);
 
-  DirectExec((
-	"INSERT INTO \"" + m_LogTable + "\" "
+  direct_exec((
+	"INSERT INTO \"" + m_log_table + "\" "
 	"(id, username, name, date) "
 	"VALUES "
 	"(" +
@@ -238,56 +226,59 @@ void pqxx::basic_robusttransaction::CreateTransactionRecord()
 }
 
 
-string pqxx::basic_robusttransaction::sql_delete() const
+std::string pqxx::internal::basic_robusttransaction::sql_delete() const
 {
-  return "DELETE FROM \"" + m_LogTable + "\" "
+  return
+	"DELETE FROM \"" + m_log_table + "\" "
 	"WHERE id = " + to_string(m_record_id);
 }
 
 
-void pqxx::basic_robusttransaction::DeleteTransactionRecord() throw ()
+void pqxx::internal::basic_robusttransaction::DeleteTransactionRecord()
+        noexcept
 {
   if (!m_record_id) return;
 
   try
   {
-    const string Del = sql_delete();
+    const std::string Del = sql_delete();
 
     reactivation_avoidance_exemption E(conn());
-    DirectExec(Del.c_str(), 20);
+    direct_exec(Del.c_str(), 20);
 
     // Now that we've arrived here, we're about as sure as we can be that that
     // record is quite dead.
     m_record_id = 0;
   }
-  catch (const exception &)
+  catch (const std::exception &)
   {
   }
 
   if (m_record_id != 0) try
   {
-    process_notice("WARNING: "
-	           "Failed to delete obsolete transaction record with id " +
-		   to_string(m_record_id) + " ('" + name() + "'). "
-		   "Please delete it manually.  Thank you.\n");
+    process_notice(
+	"WARNING: "
+	"Failed to delete obsolete transaction record with id " +
+	to_string(m_record_id) + " ('" + name() + "'). "
+	"Please delete it manually.  Thank you.\n");
   }
-  catch (const exception &)
+  catch (const std::exception &)
   {
   }
 }
 
 
 // Attempt to establish whether transaction record with given ID still exists
-bool pqxx::basic_robusttransaction::CheckTransactionRecord()
+bool pqxx::internal::basic_robusttransaction::CheckTransactionRecord()
 {
   bool hold = true;
   for (int c=20; hold && c; internal::sleep_seconds(5), --c)
   {
     if (conn().server_version() > 80300)
     {
-      const string query(
+      const std::string query(
 	"SELECT " + m_xid + " >= txid_snapshot_xmin(txid_current_snapshot())");
-      DirectExec(query.c_str())[0][0].to(hold);
+      direct_exec(query.c_str())[0][0].to(hold);
     }
     else
     {
@@ -303,7 +294,7 @@ bool pqxx::basic_robusttransaction::CheckTransactionRecord()
        * relation exists but no such record is found, then the transaction is no
        * longer running.
        */
-      const result R(DirectExec((
+      const result R(direct_exec((
 	"SELECT current_query "
 	"FROM pq_stat_activity "
 	"WHERE procpid = " + to_string(m_backendpid)).c_str()));
@@ -316,11 +307,11 @@ bool pqxx::basic_robusttransaction::CheckTransactionRecord()
 	"Old backend process stays alive too long to wait for.");
 
   // Now look for our transaction record
-  const string Find = "SELECT id FROM \"" + m_LogTable + "\" "
-	              "WHERE "
-                        "id = " + to_string(m_record_id) + " AND "
-                        "user = " + conn().username();
+  const std::string Find =
+        "SELECT id FROM \"" + m_log_table + "\" "
+        "WHERE "
+            "id = " + to_string(m_record_id) + " AND "
+            "user = " + conn().username();
 
-  return !DirectExec(Find.c_str(), 20).empty();
+  return !direct_exec(Find.c_str(), 20).empty();
 }
-
