@@ -1,82 +1,69 @@
-/*-------------------------------------------------------------------------
+/** Implementation of the pqxx::tablereader class.
  *
- *   FILE
- *	tablereader.cxx
+ * pqxx::tablereader enables optimized batch reads from a database table.
  *
- *   DESCRIPTION
- *      implementation of the pqxx::tablereader class.
- *   pqxx::tablereader enables optimized batch reads from a database table
- *
- * Copyright (c) 2001-2011, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2001-2017, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
  * or contact the author.
- *
- *-------------------------------------------------------------------------
  */
 #include "pqxx/compiler-internal.hxx"
 
-#ifdef PQXX_QUIET_DESTRUCTORS
-#include "pqxx/errorhandler"
-#endif
-
 #include "pqxx/tablereader"
 #include "pqxx/transaction"
 
 #include "pqxx/internal/gates/transaction-tablereader.hxx"
 
-using namespace PGSTD;
 using namespace pqxx::internal;
 
 
-pqxx::tablereader::tablereader(transaction_base &T,
-    const PGSTD::string &Name,
-    const PGSTD::string &Null) :
+pqxx::tablereader::tablereader(
+	transaction_base &T,
+	const std::string &Name,
+	const std::string &Null) :
   namedclass("tablereader", Name),
   tablestream(T, Null),
-  m_Done(true)
+  m_done(true)
 {
   setup(T, Name);
 }
 
-void pqxx::tablereader::setup(transaction_base &T,
-    const PGSTD::string &Name,
-    const PGSTD::string &Columns)
+void pqxx::tablereader::setup(
+	transaction_base &T,
+	const std::string &Name,
+	const std::string &Columns)
 {
   gate::transaction_tablereader(T).BeginCopyRead(Name, Columns);
   register_me();
-  m_Done = false;
+  m_done = false;
 }
 
-pqxx::tablereader::~tablereader() throw ()
+pqxx::tablereader::~tablereader() noexcept
 {
-#ifdef PQXX_QUIET_DESTRUCTORS
-  quiet_errorhandler quiet(m_Trans.conn());
-#endif
   try
   {
     reader_close();
   }
-  catch (const exception &e)
+  catch (const std::exception &e)
   {
     reg_pending_error(e.what());
   }
 }
 
 
-bool pqxx::tablereader::get_raw_line(PGSTD::string &Line)
+bool pqxx::tablereader::get_raw_line(std::string &Line)
 {
-  if (!m_Done) try
+  if (!m_done) try
   {
-    m_Done = !gate::transaction_tablereader(m_Trans).ReadCopyLine(Line);
+    m_done = !gate::transaction_tablereader(m_trans).read_copy_line(Line);
   }
-  catch (const exception &)
+  catch (const std::exception &)
   {
-    m_Done = true;
+    m_done = true;
     throw;
   }
-  return !m_Done;
+  return !m_done;
 }
 
 
@@ -93,19 +80,19 @@ void pqxx::tablereader::reader_close()
     base_close();
 
     // If any lines remain to be read, consume them to not confuse PQendcopy()
-    if (!m_Done)
+    if (!m_done)
     {
       try
       {
-        string Dummy;
+        std::string Dummy;
         while (get_raw_line(Dummy)) ;
       }
       catch (const broken_connection &)
       {
-	try { base_close(); } catch (const exception &) {}
+	try { base_close(); } catch (const std::exception &) {}
 	throw;
       }
-      catch (const exception &e)
+      catch (const std::exception &e)
       {
         reg_pending_error(e.what());
       }
@@ -116,7 +103,7 @@ void pqxx::tablereader::reader_close()
 
 namespace
 {
-inline bool is_octalchar(char o) throw ()
+inline bool is_octalchar(char o) noexcept
 {
   return (o>='0') && (o<='7');
 }
@@ -124,23 +111,25 @@ inline bool is_octalchar(char o) throw ()
 /// Find first tab character at or after start position in string
 /** If not found, returns Line.size() rather than string::npos.
  */
-string::size_type findtab(const PGSTD::string &Line,
-	PGSTD::string::size_type start)
+std::string::size_type findtab(
+	const std::string &Line,
+	std::string::size_type start)
 {
   // TODO: Fix for multibyte encodings?
-  const string::size_type here = Line.find('\t', start);
-  return (here == string::npos) ? Line.size() : here;
+  const auto here = Line.find('\t', start);
+  return (here == std::string::npos) ? Line.size() : here;
 }
 } // namespace
 
 
-string pqxx::tablereader::extract_field(const PGSTD::string &Line,
-    PGSTD::string::size_type &i) const
+std::string pqxx::tablereader::extract_field(
+	const std::string &Line,
+	std::string::size_type &i) const
 {
   // TODO: Pick better exception types
-  string R;
+  std::string R;
   bool isnull=false;
-  string::size_type stop = findtab(Line, i);
+  auto stop = findtab(Line, i);
   for (; i < stop; ++i)
   {
     const char c = Line[i];
@@ -181,7 +170,8 @@ string pqxx::tablereader::extract_field(const PGSTD::string &Line,
 	    const char n2 = Line[++i];
 	    if (!is_octalchar(n1) || !is_octalchar(n2))
 	      throw failure("Invalid octal in encoded table stream");
-	    R += char((digit_to_number(n)<<6) |
+	    R += char(
+		(digit_to_number(n)<<6) |
 		(digit_to_number(n1)<<3) |
 		digit_to_number(n2));
           }
@@ -235,4 +225,3 @@ string pqxx::tablereader::extract_field(const PGSTD::string &Line,
 
   return R;
 }
-
