@@ -1,39 +1,29 @@
-/*-------------------------------------------------------------------------
+/** Implementation of the pqxx::tablestream class.
  *
- *   FILE
- *	tablestream.cxx
+ * pqxx::tablestream provides optimized batch access to a database table.
  *
- *   DESCRIPTION
- *      implementation of the pqxx::tablestream class.
- *   pqxx::tablestream provides optimized batch access to a database table
- *
- * Copyright (c) 2001-2006, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2001-2017, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
  * or contact the author.
- *
- *-------------------------------------------------------------------------
  */
 #include "pqxx/compiler-internal.hxx"
 
 #include "pqxx/tablestream"
 #include "pqxx/transaction"
 
-using namespace PGSTD;
-
 
 pqxx::tablestream::tablestream(transaction_base &STrans,
-	const PGSTD::string &Null) :
+	const std::string &Null) :
   internal::namedclass("tablestream"),
   internal::transactionfocus(STrans),
-  m_Null(Null),
-  m_Finished(false)
+  m_null(Null)
 {
 }
 
 
-pqxx::tablestream::~tablestream() throw ()
+pqxx::tablestream::~tablestream() noexcept
 {
 }
 
@@ -42,10 +32,7 @@ void pqxx::tablestream::base_close()
 {
   if (!is_finished())
   {
-    m_Finished = true;
+    m_finished = true;
     unregister_me();
   }
 }
-
-
-
