@@ -1,39 +1,28 @@
-/*-------------------------------------------------------------------------
+/** Implementation of the pqxx::tablewriter class.
  *
- *   FILE
- *	tablewriter.cxx
+ * pqxx::tablewriter enables optimized batch updates to a database table.
  *
- *   DESCRIPTION
- *      implementation of the pqxx::tablewriter class.
- *   pqxx::tablewriter enables optimized batch updates to a database table
- *
- * Copyright (c) 2001-2011, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2001-2017, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
  * or contact the author.
- *
- *-------------------------------------------------------------------------
  */
 #include "pqxx/compiler-internal.hxx"
 
-#ifdef PQXX_QUIET_DESTRUCTORS
-#include "pqxx/errorhandler"
-#endif
-
 #include "pqxx/tablereader"
 #include "pqxx/tablewriter"
 #include "pqxx/transaction"
 
 #include "pqxx/internal/gates/transaction-tablewriter.hxx"
 
-using namespace PGSTD;
 using namespace pqxx::internal;
 
 
-pqxx::tablewriter::tablewriter(transaction_base &T,
-    const PGSTD::string &WName,
-    const PGSTD::string &Null) :
+pqxx::tablewriter::tablewriter(
+	transaction_base &T,
+	const std::string &WName,
+	const std::string &Null) :
   namedclass("tablewriter", WName),
   tablestream(T, Null)
 {
@@ -41,25 +30,23 @@ pqxx::tablewriter::tablewriter(transaction_base &T,
 }
 
 
-pqxx::tablewriter::~tablewriter() throw ()
+pqxx::tablewriter::~tablewriter() noexcept
 {
-#ifdef PQXX_QUIET_DESTRUCTORS
-  quiet_errorhandler quiet(m_Trans.conn());
-#endif
   try
   {
     writer_close();
   }
-  catch (const exception &e)
+  catch (const std::exception &e)
   {
     reg_pending_error(e.what());
   }
 }
 
 
-void pqxx::tablewriter::setup(transaction_base &T,
-    const PGSTD::string &WName,
-    const PGSTD::string &Columns)
+void pqxx::tablewriter::setup(
+	transaction_base &T,
+	const std::string &WName,
+	const std::string &Columns)
 {
   gate::transaction_tablewriter(T).BeginCopyWrite(WName, Columns);
   register_me();
@@ -68,20 +55,20 @@ void pqxx::tablewriter::setup(transaction_base &T,
 
 pqxx::tablewriter &pqxx::tablewriter::operator<<(pqxx::tablereader &R)
 {
-  string Line;
+  std::string Line;
   // TODO: Can we do this in binary mode? (Might require protocol version check)
   while (R.get_raw_line(Line)) write_raw_line(Line);
   return *this;
 }
 
 
-void pqxx::tablewriter::write_raw_line(const PGSTD::string &Line)
+void pqxx::tablewriter::write_raw_line(const std::string &Line)
 {
-  const string::size_type len = Line.size();
-  gate::transaction_tablewriter(m_Trans).WriteCopyLine(
+  const std::string::size_type len = Line.size();
+  gate::transaction_tablewriter(m_trans).write_copy_line(
 	(!len || Line[len-1] != '\n') ?
 	Line :
-	string(Line, 0, len-1));
+        std::string(Line, 0, len-1));
 }
 
 
@@ -98,11 +85,11 @@ void pqxx::tablewriter::writer_close()
     base_close();
     try
     {
-      gate::transaction_tablewriter(m_Trans).EndCopyWrite();
+      gate::transaction_tablewriter(m_trans).end_copy_write();
     }
-    catch (const exception &)
+    catch (const std::exception &)
     {
-      try { base_close(); } catch (const exception &) {}
+      try { base_close(); } catch (const std::exception &) {}
       throw;
     }
   }
@@ -111,7 +98,7 @@ void pqxx::tablewriter::writer_close()
 
 namespace
 {
-inline char escapechar(char i)
+inline char escapechar(char i) noexcept
 {
   char r = '\0';
   switch (i)
@@ -127,32 +114,32 @@ inline char escapechar(char i)
   return r;
 }
 
-inline bool unprintable(char i)
+inline bool unprintable(char i) noexcept
 {
   return i < ' ' || i > '~';
 }
 
 inline char tooctdigit(char c, int n)
 {
-  typedef unsigned char unsigned_char;
+  using unsigned_char = unsigned char;
   unsigned int i = unsigned_char(c);
   return number_to_digit((i>>(3*n)) & 0x07);
 }
 } // namespace
 
 
-string pqxx::internal::Escape(const string &s, const string &null)
+std::string pqxx::internal::escape(
+        const std::string &s,
+        const std::string &null)
 {
   if (s == null) return "\\N";
   if (s.empty()) return s;
 
-  string R;
+  std::string R;
   R.reserve(s.size()+1);
 
-  const string::const_iterator s_end(s.end());
-  for (string::const_iterator j = s.begin(); j != s_end; ++j)
+  for (const auto c: s)
   {
-    const char c = *j;
     const char e = escapechar(c);
     if (e)
     {
@@ -171,5 +158,3 @@ string pqxx::internal::Escape(const string &s, const string &null)
   }
   return R;
 }
-
-
