@@ -1,6 +1,6 @@
 #include <vector>
 
-#include <test_helpers.hxx>
+#include "../test_helpers.hxx"
 
 using namespace std;
 using namespace pqxx;
